import_path_range

Function import_path_range 

pub fn import_path_range(
    node_info: &NodeInfo,
    source_bytes: &[u8],
) -> Option<Range>
Find the LSP Range of the import path string inside an ImportDirective.

Returns the range covering just the text between the quotes in the import statement. Used by both document_links (for clickable links) and file_operations::rename_imports (for path rewriting).