pub enum ContractDefinitionNode {
UsingForDirective(UsingForDirective),
StructDefinition(StructDefinition),
EnumDefinition(EnumDefinition),
VariableDeclaration(VariableDeclaration),
EventDefinition(EventDefinition),
ErrorDefinition(ErrorDefinition),
FunctionDefinition(FunctionDefinition),
ModifierDefinition(ModifierDefinition),
UserDefinedValueTypeDefinition(UserDefinedValueTypeDefinition),
}Expand description
A node that can appear inside a contract definition’s nodes array.
Discriminated by nodeType in the JSON.
Variants
UsingForDirective(UsingForDirective)
StructDefinition(StructDefinition)
EnumDefinition(EnumDefinition)
VariableDeclaration(VariableDeclaration)
EventDefinition(EventDefinition)
ErrorDefinition(ErrorDefinition)
FunctionDefinition(FunctionDefinition)
ModifierDefinition(ModifierDefinition)
UserDefinedValueTypeDefinition(UserDefinedValueTypeDefinition)
Implementations
Sourceimpl ContractDefinitionNode
impl ContractDefinitionNode
Sourcepub fn selector(&self) -> Option<&str>
pub fn selector(&self) -> Option<&str>
Extract the function/error/event selector from this contract child node.
Returns the hex selector string (no 0x prefix):
- 4-byte for functions, public variables, and errors
- 32-byte for events
Nonefor other node types
Sourcepub fn documentation_text(&self) -> Option<String>
pub fn documentation_text(&self) -> Option<String>
Extract the documentation text from this contract child node.