Structs
Functions
- changed_
files_ since_ v2_ cache - Return absolute paths of source files whose current hash differs from v2 cache metadata (including newly-added files missing from metadata).
- load_
reference_ cache - load_
reference_ cache_ with_ report - save_
reference_ cache - save_
reference_ cache_ with_ report - upsert_
reference_ cache_ v2_ with_ report - Incrementally upsert v2 cache shards from a partial build (typically a saved file compile). This is a fast-path: it updates per-file shards and file hashes for touched files, while preserving existing global metadata.